/* Wrap some simple USB functions to provide access from python.
   Used by the ifp_core module
   
   $Id: usb_core.i,v 1.2 2005/01/24 04:51:24 milamber Exp $
   
*/

%module usb_core
%{
	#include <usb.h>

	/* Put this here so I don't have to wrap the entire struct usb_device to get this one peice of info */
	int get_dev_interface_number(struct usb_device *dev) {
		return dev->config->interface->altsetting->bInterfaceNumber;
	}
%}

int get_dev_interface_number(struct usb_device *dev);

/* Specific exception handlers. I need to do this to provide different messages */
%exception usb_claim_interface {
	$function
	if(result != 0) {
		PyErr_SetString(PyExc_IOError,"Device is busy. (I was unable to claim its interface.)");
	}
}
%exception usb_device {
	$function
	if(result == NULL) {
		PyErr_SetString(PyExc_IOError,"Unable to get USB device handle for iFP driver");
		return NULL;
	}
}
/* functions with speicific exception handlers */
int usb_claim_interface(usb_dev_handle *dev, int interface);
struct usb_device *usb_device(void *dev);

void usb_init(void);

/* functions that return 0 on success and something else on failure */
%exception {
	//fprintf(stderr,"Entering function '$name'\n");
	if(arg1 == NULL) {
		PyErr_SetString(PyExc_ValueError,"iFP device handle is NULL in function '$name'!");
		goto fail;
	}
	$function
	if(result != 0) {
		char error_message[2048];
		snprintf(error_message,2048,"Error reading information from device in function '$name'. (code %d)",result);
		PyErr_SetString(PyExc_IOError,error_message);
	}
	//fprintf(stderr,"Exiting function '$name'\n");
}

int usb_release_interface(usb_dev_handle *dev, int interface);

%exception;
